from maestro_fetch.adapters.baidu_pan import BaiduPanAdapter
from maestro_fetch.adapters.cloud import CloudAdapter
from maestro_fetch.adapters.doc import DocAdapter
from maestro_fetch.adapters.web import WebAdapter
from maestro_fetch.adapters.media import MediaAdapter

__all__ = ["BaiduPanAdapter", "CloudAdapter", "DocAdapter", "WebAdapter", "MediaAdapter"]
